library IEEE;
use IEEE.STD_LOGIC_1164.all;
use IEEE.Numeric_Std.all;

entity rom is
  port (
    clk25   : in  std_logic;
    charlin : in  std_logic_vector (11 downto 0);
    dat     : out  std_logic_vector (7 downto 0)
 );
end entity rom;

architecture RTL of rom is

type rom_type is array (0 to 1023) of std_logic_vector(0 to 7);
signal rom : rom_type :=(
   x"00", x"60", x"80", x"82", x"62", x"0e", x"12", x"0e", x"fe", x"fe", 
  x"fe", x"fe", x"fe", x"fe", x"fe", x"fe", x"00", x"42", x"c2", x"44", 
  x"44", x"e8", x"08", x"10", x"00", x"e2", x"12", x"e4", x"14", x"e8", 
  x"08", x"10", x"00", x"f2", x"82", x"e4", x"14", x"e8", x"08", x"10", 
  x"00", x"f2", x"12", x"24", x"44", x"88", x"08", x"10", x"00", x"30", 
  x"48", x"30", x"00", x"00", x"00", x"00", x"00", x"00", x"10", x"10", 
  x"fe", x"10", x"10", x"fe", x"00", x"00", x"08", x"04", x"fe", x"04", 
  x"08", x"00", x"00", x"00", x"7c", x"82", x"82", x"7c", x"00", x"00", 
  x"00", x"00", x"10", x"00", x"fe", x"00", x"10", x"00", x"00", x"10", 
  x"10", x"10", x"92", x"54", x"38", x"10", x"fe", x"00", x"00", x"00", 
  x"00", x"00", x"00", x"00", x"00", x"fe", x"00", x"00", x"00", x"00", 
  x"00", x"00", x"00", x"00", x"fe", x"00", x"00", x"00", x"00", x"00", 
  x"00", x"00", x"00", x"fe", x"00", x"00", x"00", x"00", x"00", x"00", 
  x"00", x"00", x"fe", x"00", x"00", x"00", x"00", x"00", x"00", x"00", 
  x"00", x"fe", x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"00", 
  x"fe", x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"fe", 
  x"00", x"00", x"00", x"60", x"90", x"90", x"90", x"60", x"00", x"00", 
  x"00", x"40", x"c0", x"40", x"40", x"e0", x"00", x"00", x"00", x"e0", 
  x"10", x"60", x"80", x"f0", x"00", x"00", x"00", x"e0", x"10", x"60", 
  x"10", x"e0", x"00", x"00", x"00", x"20", x"60", x"a0", x"f0", x"20", 
  x"00", x"00", x"00", x"f0", x"80", x"e0", x"10", x"e0", x"00", x"00", 
  x"00", x"70", x"80", x"e0", x"90", x"60", x"00", x"00", x"00", x"f0", 
  x"10", x"20", x"40", x"80", x"00", x"00", x"00", x"60", x"90", x"60", 
  x"90", x"60", x"00", x"00", x"00", x"60", x"90", x"70", x"10", x"e0", 
  x"00", x"7e", x"f4", x"f4", x"74", x"14", x"14", x"14", x"00", x"00", 
  x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"00", 
  x"00", x"00", x"00", x"00", x"00", x"10", x"10", x"10", x"10", x"10", 
  x"00", x"10", x"00", x"28", x"28", x"28", x"00", x"00", x"00", x"00", 
  x"00", x"28", x"28", x"fe", x"28", x"fe", x"28", x"28", x"00", x"82", 
  x"38", x"44", x"44", x"44", x"38", x"82", x"00", x"c2", x"c4", x"08", 
  x"10", x"20", x"46", x"86", x"00", x"38", x"44", x"28", x"10", x"2a", 
  x"44", x"3a", x"00", x"0c", x"08", x"10", x"00", x"00", x"00", x"00", 
  x"00", x"04", x"08", x"10", x"10", x"10", x"08", x"04", x"00", x"40", 
  x"20", x"10", x"10", x"10", x"20", x"40", x"00", x"10", x"92", x"54", 
  x"38", x"54", x"92", x"10", x"00", x"00", x"10", x"10", x"fe", x"10", 
  x"10", x"00", x"00", x"00", x"00", x"00", x"00", x"0c", x"08", x"10", 
  x"00", x"00", x"00", x"00", x"fe", x"00", x"00", x"00", x"00", x"00", 
  x"00", x"00", x"00", x"00", x"18", x"18", x"00", x"02", x"04", x"08", 
  x"10", x"20", x"40", x"80", x"00", x"38", x"44", x"8a", x"92", x"a2", 
  x"44", x"38", x"00", x"10", x"30", x"50", x"10", x"10", x"10", x"7c", 
  x"00", x"78", x"84", x"02", x"1c", x"60", x"80", x"fe", x"00", x"fe", 
  x"04", x"08", x"0c", x"02", x"82", x"7c", x"00", x"08", x"18", x"28", 
  x"48", x"fe", x"08", x"08", x"00", x"fe", x"80", x"bc", x"c2", x"02", 
  x"82", x"7c", x"00", x"3c", x"42", x"80", x"bc", x"c2", x"42", x"3c", 
  x"00", x"fe", x"02", x"04", x"08", x"10", x"20", x"40", x"00", x"7c", 
  x"82", x"82", x"7c", x"82", x"82", x"7c", x"00", x"78", x"84", x"86", 
  x"7a", x"02", x"84", x"78", x"00", x"00", x"18", x"18", x"00", x"00", 
  x"18", x"18", x"00", x"00", x"18", x"18", x"00", x"18", x"08", x"10", 
  x"00", x"04", x"08", x"10", x"20", x"10", x"08", x"04", x"00", x"00", 
  x"00", x"fe", x"00", x"fe", x"00", x"00", x"00", x"40", x"20", x"10", 
  x"08", x"10", x"20", x"40", x"00", x"7c", x"82", x"02", x"1c", x"10", 
  x"00", x"10", x"00", x"7c", x"82", x"8e", x"92", x"9c", x"80", x"7c", 
  x"00", x"10", x"28", x"44", x"82", x"fe", x"82", x"82", x"00", x"fc", 
  x"42", x"42", x"7c", x"42", x"42", x"fc", x"00", x"3c", x"42", x"80", 
  x"80", x"80", x"42", x"3c", x"00", x"fc", x"42", x"42", x"42", x"42", 
  x"42", x"fc", x"00", x"fe", x"80", x"80", x"f8", x"80", x"80", x"fe", 
  x"00", x"fe", x"80", x"80", x"f8", x"80", x"80", x"80", x"00", x"7c", 
  x"82", x"80", x"8e", x"82", x"82", x"7c", x"00", x"82", x"82", x"82", 
  x"fe", x"82", x"82", x"82", x"00", x"7c", x"10", x"10", x"10", x"10", 
  x"10", x"7c", x"00", x"02", x"02", x"02", x"02", x"02", x"82", x"7c", 
  x"00", x"82", x"8c", x"b0", x"c0", x"b0", x"8c", x"82", x"00", x"80", 
  x"80", x"80", x"80", x"80", x"80", x"fe", x"00", x"82", x"c6", x"aa", 
  x"92", x"82", x"82", x"82", x"00", x"82", x"c2", x"a2", x"92", x"8a", 
  x"86", x"82", x"00", x"7c", x"82", x"82", x"82", x"82", x"82", x"7c", 
  x"00", x"fc", x"82", x"82", x"fc", x"80", x"80", x"80", x"00", x"7c", 
  x"82", x"82", x"82", x"8a", x"84", x"7a", x"00", x"fc", x"82", x"82", 
  x"fc", x"88", x"84", x"82", x"00", x"7c", x"82", x"80", x"7c", x"02", 
  x"82", x"7c", x"00", x"fe", x"10", x"10", x"10", x"10", x"10", x"10", 
  x"00", x"82", x"82", x"82", x"82", x"82", x"82", x"7c", x"00", x"82", 
  x"82", x"44", x"44", x"28", x"28", x"10", x"00", x"82", x"82", x"82", 
  x"92", x"92", x"aa", x"44", x"00", x"82", x"44", x"28", x"10", x"28", 
  x"44", x"82", x"00", x"82", x"44", x"28", x"10", x"10", x"10", x"10", 
  x"00", x"fe", x"04", x"08", x"10", x"20", x"40", x"fe", x"00", x"7c", 
  x"60", x"60", x"60", x"60", x"60", x"7c", x"00", x"80", x"40", x"20", 
  x"10", x"08", x"04", x"02", x"00", x"7c", x"0c", x"0c", x"0c", x"0c", 
  x"0c", x"7c", x"00", x"10", x"28", x"44", x"00", x"00", x"00", x"00", 
  x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"fe", x"00", x"30", 
  x"10", x"08", x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"7c", 
  x"02", x"7e", x"82", x"7e", x"00", x"80", x"80", x"bc", x"c2", x"82", 
  x"c2", x"bc", x"00", x"00", x"00", x"7c", x"82", x"80", x"80", x"7e", 
  x"00", x"02", x"02", x"7a", x"86", x"82", x"86", x"7a", x"00", x"00", 
  x"00", x"78", x"84", x"fe", x"80", x"7c", x"00", x"0c", x"12", x"38", 
  x"10", x"10", x"10", x"10", x"00", x"00", x"00", x"3a", x"44", x"3c", 
  x"84", x"78", x"00", x"80", x"80", x"fc", x"82", x"82", x"82", x"82", 
  x"00", x"10", x"00", x"30", x"10", x"10", x"10", x"7c", x"00", x"02", 
  x"00", x"02", x"02", x"02", x"84", x"78", x"00", x"80", x"80", x"88", 
  x"90", x"a0", x"88", x"82", x"00", x"30", x"10", x"10", x"10", x"10", 
  x"10", x"38", x"00", x"00", x"00", x"ec", x"92", x"92", x"92", x"92", 
  x"00", x"00", x"00", x"bc", x"c2", x"82", x"82", x"82", x"00", x"00", 
  x"00", x"7c", x"82", x"82", x"82", x"7c", x"00", x"00", x"00", x"bc", 
  x"c2", x"fc", x"80", x"80", x"00", x"00", x"00", x"7a", x"86", x"7e", 
  x"02", x"02", x"00", x"00", x"00", x"9c", x"62", x"40", x"40", x"40", 
  x"00", x"00", x"00", x"7c", x"80", x"7c", x"02", x"fc", x"00", x"20", 
  x"20", x"70", x"20", x"20", x"24", x"18", x"00", x"00", x"00", x"84", 
  x"84", x"84", x"84", x"7a", x"00", x"00", x"00", x"82", x"82", x"44", 
  x"28", x"10", x"00", x"00", x"00", x"82", x"82", x"92", x"aa", x"44", 
  x"00", x"00", x"00", x"84", x"48", x"30", x"48", x"84", x"00", x"00", 
  x"00", x"82", x"44", x"28", x"10", x"60", x"00", x"00", x"00", x"fe", 
  x"04", x"38", x"40", x"fe", x"00", x"0e", x"10", x"10", x"60", x"10", 
  x"10", x"0e", x"00", x"10", x"10", x"10", x"10", x"10", x"10", x"10", 
  x"00", x"e0", x"10", x"10", x"0c", x"10", x"10", x"e0", x"00", x"22", 
  x"54", x"88", x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"00", 
  x"00", x"00", x"00", x"00" );

begin

process(clk25) is
begin
  if rising_edge(clk25) then
    dat <= rom((to_integer(unsigned(charlin))));
  end if;    
end process;

end architecture RTL;