library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.NUMERIC_STD.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity vga_text is
port(
  clock     : in std_logic;
  
  hsync : out std_logic;
  vsync : out std_logic;
  red   : OUT STD_LOGIC_VECTOR(3 downto 0);
  green : OUT STD_LOGIC_VECTOR(3 downto 0);
  blue  : OUT STD_LOGIC_VECTOR(3 downto 0)
  ); 
end vga_text;

architecture behavioral of vga_text is

signal clk25 : std_logic:='0';
signal we    : std_logic;

signal dataout : std_logic_vector (7 downto 0):= (others => '0');

signal char  : std_logic_vector (7 downto 0):= (others => '0');
signal dat  : std_logic_vector (7 downto 0):= (others => '0');
signal charlin  : std_logic_vector (11 downto 0):= (others => '0');

signal counterx  : std_logic_vector (9 downto 0):= (others => '0');
signal countery  : std_logic_vector (9 downto 0):= (others => '0');
signal basis  : std_logic_vector (11 downto 0):= (others => '0');
signal offs  : std_logic_vector (6 downto 0):= (others => '0');
signal zpos  : std_logic_vector (11 downto 0):= (others => '0');

signal counterxmaxed   : std_logic_vector (0 downto 0):= (others => '0');
signal counterymaxed   : std_logic_vector (0 downto 0):= (others => '0');
signal h_enable   : std_logic_vector (0 downto 0):= (others => '0');
signal v_enable   : std_logic_vector (0 downto 0):= (others => '0');
signal vid_enable   : std_logic_vector (0 downto 0):= (others => '0');
signal pixel   : std_logic_vector (0 downto 0):= (others => '0');

component ram port(
  clk25   : in  std_logic;
  we      : in  std_logic;
  zpos    : in  std_logic_vector (11 downto 0);
  char    : in  std_logic_vector (7 downto 0);
  dataout : out std_logic_vector (7 downto 0)
  );
end component;

component rom port(
  clk25   : in  std_logic;
  charlin : in  std_logic_vector (11 downto 0);
  dat     : out  std_logic_vector (7 downto 0)
  );
end component;

begin
io1 : ram  port map(clk25,we,zpos,char,dataout);
io2 : rom  port map(clk25,charlin,dat);

counterxmaxed(0) <='1' when  counterx = std_logic_vector(to_unsigned(800,counterx'length));
counterymaxed(0) <='1' when  counterx = std_logic_vector(to_unsigned(525,counterx'length));

process (clock)
begin
  if rising_edge(clock) then
    clk25 <= not clk25;
  end if;
end process;

process (clk25)
begin
  if rising_edge(clk25) then
    if counterxmaxed(0) ='1' then
      counterx <= std_logic_vector(to_unsigned(0,counterx'length));
    else
      we<='1';
      
      counterx <= counterx + std_logic_vector(to_unsigned(1,counterx'length)); 
      if dat(0)  ='1' and counterx(2 downto 0)="001" then
        pixel(0)<='1';
      elsif dat(1)='1' and counterx(2 downto 0)="010" then
        pixel(0)<='1';
      elsif dat(2)='1' and counterx(2 downto 0)="011" then
        pixel(0)<='1'; 
      elsif dat(3)='1' and counterx(2 downto 0)="100" then
        pixel(0)<='1';  
      elsif dat(4)='1' and counterx(2 downto 0)="101" then
        pixel(0)<='1';   
      elsif dat(5)='1' and counterx(2 downto 0)="110" then
        pixel(0)<='1';  
      elsif dat(6)='1' and counterx(2 downto 0)="111" then
        pixel(0)<='1'; 
      else
        pixel(0)<='1';       
      end if ;      
    end if;
    
    if counterxmaxed(0) ='1' then
      if counterymaxed(0) ='1' then 
        countery <= std_logic_vector(to_unsigned(0,countery'length));
      else  
        countery<= countery + std_logic_vector(to_unsigned(1,countery'length));      
      end if;  
    end if ; 
    
    if counterx = (2 downto 0=> '0') then
      if counterx =(counterx'range=>'0') and  countery =(countery'range=>'0') then
        basis <= std_logic_vector(to_unsigned(0,basis'length));
      elsif counterx =(counterx'range=>'0') and countery(3 downto 0) =(3 downto 0=> '0') then 
        basis<= basis + std_logic_vector(to_unsigned(80, basis'length)); 
      end if;        
    end if;    
  end if; 
  
  offs <= counterx(9 downto 3);
  zpos <= basis + offs;
end process;

process (clk25)
begin
  if rising_edge(clk25) then
     if vid_enable(0)='1' and pixel(0)='1' then
      red  <="1111";
      green<="1111";
      blue <="1111";
     else
      red  <="0000";
      green<="1111";
      blue <="0000";    
     end if;
  end if;
end process;

hsync <='1' when  counterx < std_logic_vector(to_unsigned(655,counterx'length)) or counterx > std_logic_vector(to_unsigned(751,counterx'length));
vsync <='1' when  countery < std_logic_vector(to_unsigned(489,countery'length)) or countery > std_logic_vector(to_unsigned(491,countery'length));

charlin <= std_logic_vector(to_unsigned(to_integer(unsigned(char)) + to_integer(unsigned(countery(3 downto 1))),12));

h_enable(0)   <= '1' when  counterx > std_logic_vector(to_unsigned(4,counterx'length)) and counterx < std_logic_vector(to_unsigned(640,counterx'length));
v_enable(0)   <= '1' when  countery < std_logic_vector(to_unsigned(480,countery'length)); 
vid_enable(0) <= '1' when h_enable = std_logic_vector(to_unsigned(1,h_enable'length)) and v_enable = std_logic_vector(to_unsigned(1,v_enable'length));

end behavioral;